@@ -536,6 +536,36 @@ end
 ]])
    end)
 
+   it("detects unused local value referred to from closure in incompatible branch", function()
+      assert.same({
+         {code = "311", name = "a", line = 4, column = 4, end_column = 4},
+         {code = "321", name = "a", line = 6, column = 28, end_column = 28}
+      }, check[[
+local a
+
+if (...)() then
+   a = 1
+else
+   (...)(function() return a end)
+end
+]])
+   end)
+
+   it("detects unused upvalue value referred to from closure in incompatible branch", function()
+      assert.same({
+         {code = "311", name = "a", line = 4, column = 21, end_column = 21},
+         {code = "321", name = "a", line = 6, column = 28, end_column = 28}
+      }, check[[
+local a
+
+if (...)() then
+   (...)(function() a = 1 end)
+else
+   (...)(function() return a end)
+end
+]])
+   end)
+
    it("handles upvalues before infinite loops", function()
       assert.same({
          {code = "221", name = "x", line = 1, column = 7, end_column = 7},
@@ -890,7 +920,6 @@ return foo;
    end)
 
    it("emits events, per-line options, and line lengths", function()
-      assert:set_parameter("TableFormatLevel", math.huge)
       assert.same({
          events = {
             {push = true, line = 1, column = 1, end_column = 28},
@@ -923,6 +952,32 @@ end
 ]])
    end)
 
+   it("emits correct inline option error messages", function()
+      assert.same({
+         {code = "023", line = 1, column = 1, end_column = 16},
+         {code = "022", line = 2, column = 1, end_column = 17},
+         {code = "021", msg = "unknown inline option 'something strange'", line = 3, column = 1, end_column = 30},
+         {code = "021", msg = "inline option 'std' expects 1 argument, 0 given", line = 4, column = 1, end_column = 16},
+         {code = "021", msg = "inline option 'std' expects 1 argument, 3 given", line = 5, column = 1, end_column = 30},
+         {code = "021", msg = "inline option 'no unused' expects 0 arguments, 2 given",
+            line = 6, column = 1, end_column = 43},
+         {code = "021", msg = "unknown inline option 'no ignore anything please'",
+            line = 7, column = 1, end_column = 38},
+         {code = "021", msg = "empty inline option", line = 8, column = 1, end_column = 12},
+         {code = "021", msg = "empty inline option invocation", line = 9, column = 1, end_column = 38}
+      }, check_full[[
+-- luacheck: pop
+-- luacheck: push
+-- luacheck: something strange
+-- luacheck: std
+-- luacheck: std lua51 + lua52
+-- luacheck: no unused, no unused very much
+-- luacheck: no ignore anything please
+-- luacheck:
+-- luacheck: no unused, , no redefined
+]].events)
+   end)
+
    it("handles argparse sample", function()
       assert.table(check(io.open("spec/samples/argparse.lua", "rb"):read("*a")))
    end)
