@@ -28,7 +28,7 @@ local luacov = package.loaded["luacov.runner"]
 function helper.luacheck_command(loc_path)
    loc_path = loc_path or "."
    local prefix = antipath(loc_path)
-   local cmd = ("cd %s && lua"):format(loc_path)
+   local cmd = ("cd %s && %s"):format(loc_path, arg[-5] or "lua")
 
    -- Extend package.path to allow loading this helper and luacheck modules.
    cmd = cmd..(' -e "package.path=[[%s?.lua;%ssrc%s?.lua;%ssrc%s?%sinit.lua;]]..package.path"'):format(
@@ -42,16 +42,4 @@ function helper.luacheck_command(loc_path)
    return ("%s %sbin%sluacheck.lua"):format(cmd, prefix, dir_sep)
 end
 
-function helper.before_command()
-   if luacov then
-      luacov.pause()
-   end
-end
-
-function helper.after_command()
-   if luacov then
-      luacov.resume()
-   end
-end
-
 return helper
