@@ -15,7 +15,7 @@ local function strip_locations(ast)
 end
 
 local function get_ast(src)
-   local ast = parser(src)
+   local ast = parser.parse(src)
    assert.is_table(ast)
    strip_locations(ast)
    return ast
@@ -30,15 +30,15 @@ local function get_expr(src)
 end
 
 local function get_comments(src)
-   return (select(2, parser(src)))
+   return (select(2, parser.parse(src)))
 end
 
 local function get_code_lines(src)
-   return select(3, parser(src))
+   return select(3, parser.parse(src))
 end
 
 local function get_error(src)
-   local ok, err = pcall(parser, src)
+   local ok, err = pcall(parser.parse, src)
    assert.is_false(ok)
    return err
 end
@@ -61,7 +61,10 @@ describe("parser", function()
                      {tag = "Number", "1"},
                      {tag = "String", "foo"}
                   }, get_node("return 1, 'foo'"))
-      assert.same({line = 1, column = 10, end_column = 10, msg = "expected expression near <eof>"}, get_error("return 1,"))
+      assert.same(
+         {line = 1, column = 10, end_column = 10, msg = "expected expression near <eof>"},
+         get_error("return 1,")
+      )
    end)
 
    it("parses labels correctly", function()
@@ -74,7 +77,10 @@ describe("parser", function()
    it("parses goto correctly", function()
       assert.same({tag = "Goto", "fail"}, get_node("goto fail"))
       assert.same({line = 1, column = 5, end_column = 5, msg = "expected identifier near <eof>"}, get_error("goto"))
-      assert.same({line = 1, column = 9, end_column = 9, msg = "expected statement near ','"}, get_error("goto foo, bar"))
+      assert.same(
+         {line = 1, column = 9, end_column = 9, msg = "expected statement near ','"},
+         get_error("goto foo, bar")
+      )
    end)
 
    it("parses break correctly", function()
@@ -85,9 +91,14 @@ describe("parser", function()
    it("parses do end correctly", function()
       assert.same({tag = "Do"}, get_node("do end"))
       assert.same({line = 1, column = 3, end_column = 3, msg = "expected 'end' near <eof>"}, get_error("do"))
-      assert.same({line = 1, column = 4, end_column = 8, msg = "expected 'end' near 'until'"}, get_error("do until false"))
-      assert.same({line = 2, column = 1, end_column = 5, msg = "expected 'end' (to close 'do' on line 1) near 'until'"},
-         get_error("do\nuntil false"))
+      assert.same(
+         {line = 1, column = 4, end_column = 8, msg = "expected 'end' near 'until'"},
+         get_error("do until false")
+      )
+      assert.same(
+         {line = 2, column = 1, end_column = 5, msg = "expected 'end' (to close 'do' on line 1) near 'until'"},
+         get_error("do\nuntil false")
+      )
    end)
 
    it("parses while do end correctly", function()
@@ -97,11 +108,22 @@ describe("parser", function()
                   }, get_node("while true do end"))
       assert.same({line = 1, column = 6, end_column = 6, msg = "expected condition near <eof>"}, get_error("while"))
       assert.same({line = 1, column = 11, end_column = 11, msg = "expected 'do' near <eof>"}, get_error("while true"))
-      assert.same({line = 1, column = 14, end_column = 14, msg = "expected 'end' near <eof>"}, get_error("while true do"))
-      assert.same({line = 2, column = 3, end_column = 3, msg = "expected 'end' (to close 'while' on line 1) near <eof>"},
-         get_error("while true\ndo"))
-      assert.same({line = 1, column = 7, end_column = 8, msg = "expected condition near 'do'"}, get_error("while do end"))
-      assert.same({line = 1, column = 11, end_column = 11, msg = "expected 'do' near ','"}, get_error("while true, false do end"))
+      assert.same(
+         {line = 1, column = 14, end_column = 14, msg = "expected 'end' near <eof>"},
+         get_error("while true do")
+      )
+      assert.same(
+         {line = 2, column = 3, end_column = 3, msg = "expected 'end' (to close 'while' on line 1) near <eof>"},
+         get_error("while true\ndo")
+      )
+      assert.same(
+         {line = 1, column = 7, end_column = 8, msg = "expected condition near 'do'"},
+         get_error("while do end")
+      )
+      assert.same(
+         {line = 1, column = 11, end_column = 11, msg = "expected 'do' near ','"},
+         get_error("while true, false do end")
+      )
    end)
 
    it("parses repeat until correctly", function()
@@ -110,10 +132,18 @@ describe("parser", function()
                      {tag = "True"}
                   }, get_node("repeat until true"))
       assert.same({line = 1, column = 7, end_column = 7, msg = "expected 'until' near <eof>"}, get_error("repeat"))
-      assert.same({line = 3, column = 1, end_column = 1, msg = "expected 'until' (to close 'repeat' on line 1) near <eof>"},
-         get_error("repeat\n--"))
-      assert.same({line = 1, column = 13, end_column = 13, msg = "expected condition near <eof>"}, get_error("repeat until"))
-      assert.same({line = 1, column = 18, end_column = 18, msg = "expected statement near ','"}, get_error("repeat until true, false"))
+      assert.same(
+         {line = 3, column = 1, end_column = 1, msg = "expected 'until' (to close 'repeat' on line 1) near <eof>"},
+         get_error("repeat\n--")
+      )
+      assert.same(
+         {line = 1, column = 13, end_column = 13, msg = "expected condition near <eof>"},
+         get_error("repeat until")
+      )
+      assert.same(
+         {line = 1, column = 18, end_column = 18, msg = "expected statement near ','"},
+         get_error("repeat until true, false")
+      )
    end)
 
    describe("when parsing if", function()
@@ -124,11 +154,22 @@ describe("parser", function()
                      }, get_node("if true then end"))
          assert.same({line = 1, column = 3, end_column = 3, msg = "expected condition near <eof>"}, get_error("if"))
          assert.same({line = 1, column = 8, end_column = 8, msg = "expected 'then' near <eof>"}, get_error("if true"))
-         assert.same({line = 1, column = 13, end_column = 13, msg = "expected 'end' near <eof>"}, get_error("if true then"))
-         assert.same({line = 2, column = 5, end_column = 5, msg = "expected 'end' (to close 'if' on line 1) near <eof>"},
-            get_error("if true\nthen"))
-         assert.same({line = 1, column = 4, end_column = 7, msg = "expected condition near 'then'"}, get_error("if then end"))
-         assert.same({line = 1, column = 8, end_column = 8, msg = "expected 'then' near ','"}, get_error("if true, false then end"))
+         assert.same(
+            {line = 1, column = 13, end_column = 13, msg = "expected 'end' near <eof>"},
+            get_error("if true then")
+         )
+         assert.same(
+            {line = 2, column = 5, end_column = 5, msg = "expected 'end' (to close 'if' on line 1) near <eof>"},
+            get_error("if true\nthen")
+         )
+         assert.same(
+            {line = 1, column = 4, end_column = 7, msg = "expected condition near 'then'"},
+            get_error("if then end")
+         )
+         assert.same(
+            {line = 1, column = 8, end_column = 8, msg = "expected 'then' near ','"},
+            get_error("if true, false then end")
+         )
       end)
 
       it("parses if then else end correctly", function()
@@ -137,10 +178,18 @@ describe("parser", function()
                         {},
                         {}
                      }, get_node("if true then else end"))
-         assert.same({line = 1, column = 18, end_column = 18, msg = "expected 'end' near <eof>"}, get_error("if true then else"))
-         assert.same({line = 3, column = 1, end_column = 1, msg = "expected 'end' (to close 'else' on line 2) near <eof>"},
-            get_error("if true\nthen else\n"))
-         assert.same({line = 1, column = 19, end_column = 22, msg = "expected 'end' near 'else'"}, get_error("if true then else else end"))
+         assert.same(
+            {line = 1, column = 18, end_column = 18, msg = "expected 'end' near <eof>"},
+            get_error("if true then else")
+         )
+         assert.same(
+            {line = 3, column = 1, end_column = 1, msg = "expected 'end' (to close 'else' on line 2) near <eof>"},
+            get_error("if true\nthen else\n")
+         )
+         assert.same(
+            {line = 1, column = 19, end_column = 22, msg = "expected 'end' near 'else'"},
+            get_error("if true then else else end")
+         )
       end)
 
       it("parses if then elseif then end correctly", function()
@@ -150,10 +199,18 @@ describe("parser", function()
                         {tag = "False"},
                         {}
                      }, get_node("if true then elseif false then end"))
-         assert.same({line = 1, column = 21, end_column = 23, msg = "expected condition near 'end'"}, get_error("if true then elseif end"))
-         assert.same({line = 1, column = 21, end_column = 24, msg = "expected condition near 'then'"}, get_error("if true then elseif then end"))
-         assert.same({line = 2, column = 5, end_column = 5, msg = "expected 'end' (to close 'elseif' on line 1) near <eof>"},
-            get_error("if true then elseif a\nthen"))
+         assert.same(
+            {line = 1, column = 21, end_column = 23, msg = "expected condition near 'end'"},
+            get_error("if true then elseif end")
+         )
+         assert.same(
+            {line = 1, column = 21, end_column = 24, msg = "expected condition near 'then'"},
+            get_error("if true then elseif then end")
+         )
+         assert.same(
+            {line = 2, column = 5, end_column = 5, msg = "expected 'end' (to close 'elseif' on line 1) near <eof>"},
+            get_error("if true then elseif a\nthen")
+         )
       end)
 
       it("parses if then elseif then else end correctly", function()
@@ -164,7 +221,10 @@ describe("parser", function()
                         {},
                         {}
                      }, get_node("if true then elseif false then else end"))
-         assert.same({line = 1, column = 36, end_column = 36, msg = "expected 'end' near <eof>"}, get_error("if true then elseif false then else"))
+         assert.same(
+            {line = 1, column = 36, end_column = 36, msg = "expected 'end' near <eof>"},
+            get_error("if true then elseif false then else")
+         )
       end)
    end)
 
@@ -176,15 +236,38 @@ describe("parser", function()
                         {tag = "Op", "len", {tag = "Id", "t"}},
                         {}
                      }, get_node("for i=1, #t do end"))
-         assert.same({line = 1, column = 4, end_column = 4, msg = "expected identifier near <eof>"}, get_error("for"))
-         assert.same({line = 1, column = 6, end_column = 6, msg = "expected '=', ',' or 'in' near <eof>"}, get_error("for i"))
-         assert.same({line = 1, column = 7, end_column = 8, msg = "expected '=', ',' or 'in' near '~='"}, get_error("for i ~= 2"))
-         assert.same({line = 1, column = 11, end_column = 12, msg = "expected ',' near 'do'"}, get_error("for i = 2 do end"))
-         assert.same({line = 1, column = 15, end_column = 15, msg = "expected 'end' near <eof>"}, get_error("for i=1, #t do"))
-         assert.same({line = 2, column = 4, end_column = 4, msg = "expected 'end' (to close 'for' on line 1) near <eof>"},
-            get_error("for i=1, #t do\na()"))
-         assert.same({line = 1, column = 5, end_column = 5, msg = "expected identifier near '('"}, get_error("for (i)=1, #t do end"))
-         assert.same({line = 1, column = 5, end_column = 5, msg = "expected identifier near '3'"}, get_error("for 3=1, #t do end"))
+         assert.same(
+            {line = 1, column = 4, end_column = 4, msg = "expected identifier near <eof>"},
+            get_error("for")
+         )
+         assert.same(
+            {line = 1, column = 6, end_column = 6, msg = "expected '=', ',' or 'in' near <eof>"},
+            get_error("for i")
+         )
+         assert.same(
+            {line = 1, column = 7, end_column = 8, msg = "expected '=', ',' or 'in' near '~='"},
+            get_error("for i ~= 2")
+         )
+         assert.same(
+            {line = 1, column = 11, end_column = 12, msg = "expected ',' near 'do'"},
+            get_error("for i = 2 do end")
+         )
+         assert.same(
+            {line = 1, column = 15, end_column = 15, msg = "expected 'end' near <eof>"},
+            get_error("for i=1, #t do")
+         )
+         assert.same(
+            {line = 2, column = 4, end_column = 4, msg = "expected 'end' (to close 'for' on line 1) near <eof>"},
+            get_error("for i=1, #t do\na()")
+         )
+         assert.same(
+            {line = 1, column = 5, end_column = 5, msg = "expected identifier near '('"},
+            get_error("for (i)=1, #t do end")
+         )
+         assert.same(
+            {line = 1, column = 5, end_column = 5, msg = "expected identifier near '3'"},
+            get_error("for 3=1, #t do end")
+         )
       end)
 
       it("parses fornum with step correctly", function()
@@ -195,7 +278,10 @@ describe("parser", function()
                         {tag = "Number", "2"},
                         {}
                      }, get_node("for i=1, #t, 2 do end"))
-         assert.same({line = 1, column = 15, end_column = 15, msg = "expected 'do' near ','"}, get_error("for i=1, #t, 2, 3 do"))
+         assert.same(
+            {line = 1, column = 15, end_column = 15, msg = "expected 'do' near ','"},
+            get_error("for i=1, #t, 2, 3 do")
+         )
       end)
 
       it("parses forin correctly", function()
@@ -215,8 +301,14 @@ describe("parser", function()
                         },
                         {}
                      }, get_node("for i, j in t, 'foo' do end"))
-         assert.same({line = 1, column = 5, end_column = 6, msg = "expected identifier near 'in'"}, get_error("for in foo do end"))
-         assert.same({line = 1, column = 10, end_column = 11, msg = "expected expression near 'do'"}, get_error("for i in do end"))
+         assert.same(
+            {line = 1, column = 5, end_column = 6, msg = "expected identifier near 'in'"},
+            get_error("for in foo do end")
+         )
+         assert.same(
+            {line = 1, column = 10, end_column = 11, msg = "expected expression near 'do'"},
+            get_error("for i in do end")
+         )
       end)
    end)
 
@@ -228,16 +320,42 @@ describe("parser", function()
                            {tag = "Function", {}, {}}
                         }
                      }, get_node("function a() end"))
-         assert.same({line = 1, column = 9, end_column = 9, msg = "expected identifier near <eof>"}, get_error("function"))
-         assert.same({line = 1, column = 11, end_column = 11, msg = "expected '(' near <eof>"}, get_error("function a"))
-         assert.same({line = 1, column = 12, end_column = 12, msg = "expected argument near <eof>"}, get_error("function a("))
-         assert.same({line = 1, column = 13, end_column = 13, msg = "expected 'end' near <eof>"}, get_error("function a()"))
-         assert.same({line = 2, column = 2, end_column = 2, msg = "expected 'end' (to close 'function' on line 1) near <eof>"},
-            get_error("function a(\n)"))
-         assert.same({line = 1, column = 10, end_column = 10, msg = "expected identifier near '('"}, get_error("function (a)()"))
-         assert.same({line = 1, column = 9, end_column = 9, msg = "expected identifier near '('"}, get_error("function() end"))
-         assert.same({line = 1, column = 11, end_column = 11, msg = "expected '(' near 'a'"}, get_error("(function a() end)"))
-         assert.same({line = 1, column = 18, end_column = 18, msg = "expected expression near ')'"}, get_error("function a() end()"))
+         assert.same(
+            {line = 1, column = 9, end_column = 9, msg = "expected identifier near <eof>"},
+            get_error("function")
+         )
+         assert.same(
+            {line = 1, column = 11, end_column = 11, msg = "expected '(' near <eof>"},
+            get_error("function a")
+         )
+         assert.same(
+            {line = 1, column = 12, end_column = 12, msg = "expected argument near <eof>"},
+            get_error("function a(")
+         )
+         assert.same(
+            {line = 1, column = 13, end_column = 13, msg = "expected 'end' near <eof>"},
+            get_error("function a()")
+         )
+         assert.same(
+            {line = 2, column = 2, end_column = 2, msg = "expected 'end' (to close 'function' on line 1) near <eof>"},
+            get_error("function a(\n)")
+         )
+         assert.same(
+            {line = 1, column = 10, end_column = 10, msg = "expected identifier near '('"},
+            get_error("function (a)()")
+         )
+         assert.same(
+            {line = 1, column = 9, end_column = 9, msg = "expected identifier near '('"},
+            get_error("function() end")
+         )
+         assert.same(
+            {line = 1, column = 11, end_column = 11, msg = "expected '(' near 'a'"},
+            get_error("(function a() end)")
+         )
+         assert.same(
+            {line = 1, column = 18, end_column = 18, msg = "expected expression near ')'"},
+            get_error("function a() end()")
+         )
       end)
 
       it("parses simple function with arguments correctly", function()
@@ -259,12 +377,26 @@ describe("parser", function()
                            {tag = "Function", {{tag = "Id", "b"}, {tag = "Dots", "..."}}, {}}
                         }
                      }, get_node("function a(b, ...) end"))
-         assert.same({line = 1, column = 15, end_column = 15, msg = "expected argument near ')'"}, get_error("function a(b, ) end"))
-         assert.same({line = 1, column = 13, end_column = 13, msg = "expected ')' near '.'"}, get_error("function a(b.c) end"))
-         assert.same({line = 2, column = 2, end_column = 2, msg = "expected ')' (to close '(' on line 1) near '.'"},
-            get_error("function a(\nb.c) end"))
-         assert.same({line = 1, column = 12, end_column = 12, msg = "expected argument near '('"}, get_error("function a((b)) end"))
-         assert.same({line = 1, column = 15, end_column = 15, msg = "expected ')' near ','"}, get_error("function a(..., ...) end"))
+         assert.same(
+            {line = 1, column = 15, end_column = 15, msg = "expected argument near ')'"},
+            get_error("function a(b, ) end")
+         )
+         assert.same(
+            {line = 1, column = 13, end_column = 13, msg = "expected ')' near '.'"},
+            get_error("function a(b.c) end")
+         )
+         assert.same(
+            {line = 2, column = 2, end_column = 2, msg = "expected ')' (to close '(' on line 1) near '.'"},
+            get_error("function a(\nb.c) end")
+         )
+         assert.same(
+            {line = 1, column = 12, end_column = 12, msg = "expected argument near '('"},
+            get_error("function a((b)) end")
+         )
+         assert.same(
+            {line = 1, column = 15, end_column = 15, msg = "expected ')' near ','"},
+            get_error("function a(..., ...) end")
+         )
       end)
 
       it("parses field function correctly", function()
@@ -283,8 +415,14 @@ describe("parser", function()
                            {tag = "Function", {}, {}}
                         }
                      }, get_node("function a.b.c() end"))
-         assert.same({line = 1, column = 11, end_column = 11, msg = "expected '(' near '['"}, get_error("function a[b]() end"))
-         assert.same({line = 1, column = 12, end_column = 12, msg = "expected identifier near '('"}, get_error("function a.() end"))
+         assert.same(
+            {line = 1, column = 11, end_column = 11, msg = "expected '(' near '['"},
+            get_error("function a[b]() end")
+         )
+         assert.same(
+            {line = 1, column = 12, end_column = 12, msg = "expected identifier near '('"},
+            get_error("function a.() end")
+         )
       end)
 
       it("parses method function correctly", function()
@@ -303,7 +441,10 @@ describe("parser", function()
                            {tag = "Function", {{tag = "Id", "self", implicit = true}}, {}}
                         }
                      }, get_node("function a.b:c() end"))
-         assert.same({line = 1, column = 13, end_column = 13, msg = "expected '(' near '.'"}, get_error("function a:b.c() end"))
+         assert.same(
+            {line = 1, column = 13, end_column = 13, msg = "expected '(' near '.'"},
+            get_error("function a:b.c() end")
+         )
       end)
    end)
 
@@ -318,11 +459,26 @@ describe("parser", function()
                            {tag = "Id", "b"}
                         }
                      }, get_node("local a, b"))
-         assert.same({line = 1, column = 6, end_column = 6, msg = "expected identifier near <eof>"}, get_error("local"))
-         assert.same({line = 1, column = 9, end_column = 9, msg = "expected identifier near <eof>"}, get_error("local a,"))
-         assert.same({line = 1, column = 8, end_column = 8, msg = "expected statement near '.'"}, get_error("local a.b"))
-         assert.same({line = 1, column = 8, end_column = 8, msg = "expected statement near '['"}, get_error("local a[b]"))
-         assert.same({line = 1, column = 7, end_column = 7, msg = "expected identifier near '('"}, get_error("local (a)"))
+         assert.same(
+            {line = 1, column = 6, end_column = 6, msg = "expected identifier near <eof>"},
+            get_error("local")
+         )
+         assert.same(
+            {line = 1, column = 9, end_column = 9, msg = "expected identifier near <eof>"},
+            get_error("local a,")
+         )
+         assert.same(
+            {line = 1, column = 8, end_column = 8, msg = "expected statement near '.'"},
+            get_error("local a.b")
+         )
+         assert.same(
+            {line = 1, column = 8, end_column = 8, msg = "expected statement near '['"},
+            get_error("local a[b]")
+         )
+         assert.same(
+            {line = 1, column = 7, end_column = 7, msg = "expected identifier near '('"},
+            get_error("local (a)")
+         )
       end)
 
       it("parses local declaration with assignment correctly", function()
@@ -340,11 +496,26 @@ describe("parser", function()
                            {tag = "Id", "d"}
                         }
                      }, get_node("local a, b = c, d"))
-         assert.same({line = 1, column = 11, end_column = 11, msg = "expected expression near <eof>"}, get_error("local a = "))
-         assert.same({line = 1, column = 13, end_column = 13, msg = "expected expression near <eof>"}, get_error("local a = b,"))
-         assert.same({line = 1, column = 8, end_column = 8, msg = "expected statement near '.'"}, get_error("local a.b = c"))
-         assert.same({line = 1, column = 8, end_column = 8, msg = "expected statement near '['"}, get_error("local a[b] = c"))
-         assert.same({line = 1, column = 10, end_column = 10, msg = "expected identifier near '('"}, get_error("local a, (b) = c"))
+         assert.same(
+            {line = 1, column = 11, end_column = 11, msg = "expected expression near <eof>"},
+            get_error("local a = ")
+         )
+         assert.same(
+            {line = 1, column = 13, end_column = 13, msg = "expected expression near <eof>"},
+            get_error("local a = b,")
+         )
+         assert.same(
+            {line = 1, column = 8, end_column = 8, msg = "expected statement near '.'"},
+            get_error("local a.b = c")
+         )
+         assert.same(
+            {line = 1, column = 8, end_column = 8, msg = "expected statement near '['"},
+            get_error("local a[b] = c")
+         )
+         assert.same(
+            {line = 1, column = 10, end_column = 10, msg = "expected identifier near '('"},
+            get_error("local a, (b) = c")
+         )
       end)
 
       it("parses local function declaration correctly", function()
@@ -352,8 +523,14 @@ describe("parser", function()
                         {tag = "Id", "a"},
                         {tag = "Function", {}, {}}
                      }, get_node("local function a() end"))
-         assert.same({line = 1, column = 15, end_column = 15, msg = "expected identifier near <eof>"}, get_error("local function"))
-         assert.same({line = 1, column = 17, end_column = 17, msg = "expected '(' near '.'"}, get_error("local function a.b() end"))
+         assert.same(
+            {line = 1, column = 15, end_column = 15, msg = "expected identifier near <eof>"},
+            get_error("local function")
+         )
+         assert.same(
+            {line = 1, column = 17, end_column = 17, msg = "expected '(' near '.'"},
+            get_error("local function a.b() end")
+         )
       end)
    end)
 
@@ -408,12 +585,30 @@ describe("parser", function()
                            {tag = "Id", "d"}
                         }
                      }, get_node("a, b = c, d"))
-         assert.same({line = 1, column = 5, end_column = 5, msg = "expected '=' near <eof>"}, get_error("a, b"))
-         assert.same({line = 1, column = 4, end_column = 4, msg = "expected identifier or field near '='"}, get_error("a, = b"))
-         assert.same({line = 1, column = 8, end_column = 8, msg = "expected expression near <eof>"}, get_error("a, b = "))
-         assert.same({line = 1, column = 10, end_column = 10, msg = "expected expression near <eof>"}, get_error("a, b = c,"))
-         assert.same({line = 1, column = 8, end_column = 8, msg = "expected call or indexing near '='"}, get_error("a, b() = c"))
-         assert.same({line = 1, column = 4, end_column = 4, msg = "expected identifier or field near '('"}, get_error("a, (b) = c"))
+         assert.same(
+            {line = 1, column = 5, end_column = 5, msg = "expected '=' near <eof>"},
+            get_error("a, b")
+         )
+         assert.same(
+            {line = 1, column = 4, end_column = 4, msg = "expected identifier or field near '='"},
+            get_error("a, = b")
+         )
+         assert.same(
+            {line = 1, column = 8, end_column = 8, msg = "expected expression near <eof>"},
+            get_error("a, b = ")
+         )
+         assert.same(
+            {line = 1, column = 10, end_column = 10, msg = "expected expression near <eof>"},
+            get_error("a, b = c,")
+         )
+         assert.same(
+            {line = 1, column = 8, end_column = 8, msg = "expected call or indexing near '='"},
+            get_error("a, b() = c")
+         )
+         assert.same(
+            {line = 1, column = 4, end_column = 4, msg = "expected identifier or field near '('"},
+            get_error("a, (b) = c")
+         )
       end)
    end)
 
@@ -457,8 +652,10 @@ describe("parser", function()
          assert.same({line = 2, column = 1, end_column = 2, msg = "expected ')' (to close '(' on line 1) near 'cc'"},
             get_error("(a\ncc"))
          assert.same({line = 1, column = 1, end_column = 1, msg = "expected statement near '1'"}, get_error("1()"))
-         assert.same({line = 1, column = 1, end_column = 5, msg = "expected statement near ''foo''"}, get_error("'foo'()"))
-         assert.same({line = 1, column = 9, end_column = 9, msg = "expected identifier near '('"}, get_error("function() end ()"))
+         assert.same({line = 1, column = 1, end_column = 5, msg = "expected statement near ''foo''"},
+            get_error("'foo'()"))
+         assert.same({line = 1, column = 9, end_column = 9, msg = "expected identifier near '('"},
+            get_error("function() end ()"))
       end)
 
       it("parses method calls correctly", function()
@@ -500,8 +697,10 @@ describe("parser", function()
                      }, get_node("a:b():c()"))
          assert.same({line = 1, column = 1, end_column = 1, msg = "expected statement near '1'"}, get_error("1:b()"))
          assert.same({line = 1, column = 1, end_column = 2, msg = "expected statement near ''''"}, get_error("'':a()"))
-         assert.same({line = 1, column = 9, end_column = 9, msg = "expected identifier near '('"}, get_error("function()end:b()"))
-         assert.same({line = 1, column = 4, end_column = 4, msg = "expected method arguments near ':'"}, get_error("a:b:c()"))
+         assert.same({line = 1, column = 9, end_column = 9, msg = "expected identifier near '('"},
+            get_error("function()end:b()"))
+         assert.same({line = 1, column = 4, end_column = 4, msg = "expected method arguments near ':'"},
+            get_error("a:b:c()"))
          assert.same({line = 1, column = 3, end_column = 3, msg = "expected identifier near <eof>"}, get_error("a:"))
       end)
    end)
@@ -549,16 +748,21 @@ describe("parser", function()
                         {tag = "Id", "b"},
                         {tag = "Id", "c"}
                      }, get_expr("{a; b, c;}"))
-         assert.same({line = 1, column = 9, end_column = 9, msg = "expected expression near ';'"}, get_error("return {;}"))
-         assert.same({line = 1, column = 9, end_column = 9, msg = "expected expression near <eof>"}, get_error("return {"))
-         assert.same({line = 1, column = 11, end_column = 13, msg = "expected '}' near 'end'"}, get_error("return {a end"))
+         assert.same({line = 1, column = 9, end_column = 9, msg = "expected expression near ';'"},
+            get_error("return {;}"))
+         assert.same({line = 1, column = 9, end_column = 9, msg = "expected expression near <eof>"},
+            get_error("return {"))
+         assert.same({line = 1, column = 11, end_column = 13, msg = "expected '}' near 'end'"},
+            get_error("return {a end"))
          assert.same({line = 2, column = 1, end_column = 3, msg = "expected '}' (to close '{' on line 1) near 'end'"},
             get_error("return {a\nend"))
          assert.same({line = 1, column = 11, end_column = 11, msg = "expected ']' near <eof>"}, get_error("return {[a"))
          assert.same({line = 2, column = 2, end_column = 2, msg = "expected ']' (to close '[' on line 1) near <eof>"},
             get_error("return {[\na"))
-         assert.same({line = 1, column = 11, end_column = 11, msg = "expected expression near ','"}, get_error("return {a,,}"))
-         assert.same({line = 1, column = 13, end_column = 13, msg = "expected expression near <eof>"}, get_error("return {a = "))
+         assert.same({line = 1, column = 11, end_column = 11, msg = "expected expression near ','"},
+            get_error("return {a,,}"))
+         assert.same({line = 1, column = 13, end_column = 13, msg = "expected expression near <eof>"},
+            get_error("return {a = "))
       end)
 
       it("wraps last element in table constructors in parens when needed", function()
@@ -723,13 +927,20 @@ describe("parser", function()
       end)
 
       it("does not allow statements after return", function()
-         assert.same({line = 1, column = 8, end_column = 12, msg = "expected expression near 'break'"}, get_error("return break"))
-         assert.same({line = 1, column = 9, end_column = 13, msg = "expected end of block near 'break'"}, get_error("return; break"))
-         assert.same({line = 1, column = 8, end_column = 8, msg = "expected end of block near ';'"}, get_error("return;;"))
-         assert.same({line = 1, column = 10, end_column = 14, msg = "expected end of block near 'break'"}, get_error("return 1 break"))
-         assert.same({line = 1, column = 11, end_column = 15, msg = "expected end of block near 'break'"}, get_error("return 1; break"))
-         assert.same({line = 1, column = 13, end_column = 17, msg = "expected end of block near 'break'"}, get_error("return 1, 2 break"))
-         assert.same({line = 1, column = 14, end_column = 18, msg = "expected end of block near 'break'"}, get_error("return 1, 2; break"))
+         assert.same({line = 1, column = 8, end_column = 12, msg = "expected expression near 'break'"},
+            get_error("return break"))
+         assert.same({line = 1, column = 9, end_column = 13, msg = "expected end of block near 'break'"},
+            get_error("return; break"))
+         assert.same({line = 1, column = 8, end_column = 8, msg = "expected end of block near ';'"},
+            get_error("return;;"))
+         assert.same({line = 1, column = 10, end_column = 14, msg = "expected end of block near 'break'"},
+            get_error("return 1 break"))
+         assert.same({line = 1, column = 11, end_column = 15, msg = "expected end of block near 'break'"},
+            get_error("return 1; break"))
+         assert.same({line = 1, column = 13, end_column = 17, msg = "expected end of block near 'break'"},
+            get_error("return 1, 2 break"))
+         assert.same({line = 1, column = 14, end_column = 18, msg = "expected end of block near 'break'"},
+            get_error("return 1, 2; break"))
       end)
 
       it("parses nested statements correctly", function()
@@ -897,9 +1108,11 @@ end
                               },
                               {
                                  {tag = "If", location = {line = 7, column = 4, offset = 106}, first_token = "if",
-                                    {tag = "Id", "arg", location = {line = 7, column = 7, offset = 109}, first_token = "arg"},
+                                    {tag = "Id", "arg", location = {line = 7, column = 7, offset = 109},
+                                       first_token = "arg"},
                                     {location = {line = 7, column = 11, offset = 113}, -- Branch location.
-                                       {tag = "Call", location = {line = 8, column = 7, offset = 124}, first_token = "print",
+                                       {tag = "Call", location = {line = 8, column = 7, offset = 124},
+                                             first_token = "print",
                                           {tag = "Id", "print", location = {line = 8, column = 7, offset = 124}},
                                           {tag = "Id", "arg", location = {line = 8, column = 13, offset = 130}}
                                        }
@@ -909,7 +1122,7 @@ end
                            }
                         }
                      }
-                  }, (parser([[
+                  }, (parser.parse([[
 local function foo(a, b, c, ...)
    local d = (a + b) * c
    return d, (...)
@@ -926,10 +1139,10 @@ end
 
    it("provides correct location info for labels", function()
       assert.same({
-                     {tag = "Label", "foo", location = {line = 1, column = 1, offset = 1}, end_column = 7, first_token = "::"},
-                     {tag = "Label", "bar", location = {line = 2, column = 1, offset = 9}, end_column = 6, first_token = "::"},
-                     {tag = "Label", "baz", location = {line = 3, column = 3, offset = 18}, end_column = 4, first_token = "::"}
-                  }, (parser([[
+         {tag = "Label", "foo", location = {line = 1, column = 1, offset = 1}, end_column = 7, first_token = "::"},
+         {tag = "Label", "bar", location = {line = 2, column = 1, offset = 9}, end_column = 6, first_token = "::"},
+         {tag = "Label", "baz", location = {line = 3, column = 3, offset = 18}, end_column = 4, first_token = "::"}
+      }, (parser.parse([[
 ::foo::
 :: bar
 ::::
@@ -960,7 +1173,7 @@ baz::
                            {tag = "Number", "2", location = {line = 3, column = 14, offset = 26}}
                         }
                      }
-                  }, (parser([[
+                  }, (parser.parse([[
 a();
 (b)();
 ((c).d)[3] = 2
@@ -973,7 +1186,7 @@ a();
                         {tag = "Id", "x", location = {line = 1, column = 5, offset = 5}, first_token = "x"},
                         {location = {line = 1, column = 8, offset = 8}}
                      }
-                  }, (parser([[
+                  }, (parser.parse([[
 if (x) then end
 ]])))
    end)
@@ -993,7 +1206,7 @@ if (x) then end
                            {tag = "Id", "z", location = {line = 1, column = 26, offset = 26}, first_token = "z"}
                         }
                      }
-                  }, (parser([[
+                  }, (parser.parse([[
 return {a = b, [x] = y, (z)}
 ]])))
    end)
@@ -1028,13 +1241,15 @@ long comment]=]
       end)
 
       it("provides lines with code correctly", function()
-         -- EOS is considered "code" (which does not matter w.r.t inline options).
-         assert.same({nil, true, true, true, true, true, nil, nil, true, true, true}, get_code_lines([[
+         assert.same({nil, true, true, true, true, true, true, true, true, nil, nil, true, true}, get_code_lines([[
 -- nothing here
 local foo = 2
 +
 3
 +
+[=[
+]=]
++
 {
    --[=[empty]=]
 
